#import "BarcodeReaderSdkPlugin.h"
#if __has_include(<barcode_reader_sdk/barcode_reader_sdk-Swift.h>)
#import <barcode_reader_sdk/barcode_reader_sdk-Swift.h>
#else
// Support project import fallback if the generated compatibility header
// is not copied when this plugin is created as a library.
// https://forums.swift.org/t/swift-static-libraries-dont-copy-generated-objective-c-header/19816
#import "barcode_reader_sdk-Swift.h"
#endif

@implementation BarcodeReaderSdkPlugin
{
  DynamsoftBarcodeReader *barcodeReader;
}

+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
    FlutterMethodChannel* channel = [FlutterMethodChannel
      methodChannelWithName:@"barcode_reader_sdk"
            binaryMessenger:[registrar messenger]];
  BarcodeReaderPlugin* instance = [[BarcodeReaderPlugin alloc] init];
  [registrar addMethodCallDelegate:instance channel:channel];
  [SwiftBarcodeReaderSdkPlugin registerWithRegistrar:registrar];
}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
  NSString *value = call.arguments[0];
  if ([@"getPlatformVersion" isEqualToString:call.method]) {
    result([@"iOS " stringByAppendingString:[[UIDevice currentDevice] systemVersion]]);
  }
  else if ([@"initLicense" isEqualToString:call.method]) {
    barcodeReader = [[DynamsoftBarcodeReader alloc] initWithLicense:value];
  }
  else if ([@"decodeFile" isEqualToString:call.method]) {
    if (barcodeReader != nil) {
      NSArray* results = [barcodeReader decodeFileWithName:value templateName:@"" error:nil];
      if(results == nil) {
        result(@"No Barcode Detected.");
      }
      else {
        iTextResult* barcode = (iTextResult*)results.firstObject;
        if (barcode.barcodeText == nil) {
          result(@"No Barcode Detected.");
        }
        else {
          NSString* msgText = [NSString stringWithFormat:@"Format: %@, Text: %@.", barcode.barcodeFormatString, barcode.barcodeText];
          result(msgText);
        }
      }
    }
    else {
      result(@"Failed to create barcode reader!");
    }
  }
  else {
    result(FlutterMethodNotImplemented);
  }
}
@end
